@@ -186,7 +186,7 @@ $translations = array(
 	'original' => 'original',
 	'Tables have been dropped.' => 'As Tabelas foram eliminadas.',
 	'%d item(s) have been affected.' => array('%d item foi afetado.', '%d itens foram afetados.'),
-	'whole result' => 'resultado completo',
+	'Whole result' => 'Resultado completo',
 	'Clone' => 'Clonar',
 	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Quantidade máxima de campos permitidos excedidos. Por favor aumente %s.',
 	'Partition by' => 'Particionar por',
