@@ -13,6 +13,7 @@ page_header(lang('Process list'), $error);
 ?>
 
 <form action="" method="post">
+<div class="scrollable">
 <table cellspacing="0" class="nowrap checkable">
 <?php
 echo script("mixin(qsl('table'), {onclick: tableClick, ondblclick: partialArg(tableClick, true)});");
@@ -45,6 +46,7 @@ foreach (process_list() as $i => $row) {
 }
 ?>
 </table>
+</div>
 <p>
 <?php
 if (support("kill")) {
